==> sca-patterns-sle15-1.5.5.tar.gz: sca-patterns-sle15-1.5.5/patterns/SLE/sle15sp3/bind_SUSE-SU-2022_0151-1_15.3.py <==
#!/usr/bin/python3
#
# Title:       Moderate Security Announcement for bind SUSE-SU-2022:0151-1
# Description: Security fixes for SUSE Linux Enterprise 15 SP3
# Source:      Security Announcement Parser v1.6.4
# Modified:    2022 May 06
#
##############################################################################
# Copyright (C) 2022 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "bind"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2022-January/010047.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'bind'
MAIN = ''
SEVERITY = 'Moderate'
TAG = 'SUSE-SU-2022:0151-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 15):
	if ( SERVER['DistroPatchLevel'] == 3 ):
		PACKAGES = {
			'bind-debuginfo': '9.16.6-150300.22.13.1',
			'bind-debugsource': '9.16.6-150300.22.13.1',
			'bind-devel': '9.16.6-150300.22.13.1',
			'bind-utils': '9.16.6-150300.22.13.1',
			'bind-utils-debuginfo': '9.16.6-150300.22.13.1',
			'libbind9-1600': '9.16.6-150300.22.13.1',
			'libbind9-1600-debuginfo': '9.16.6-150300.22.13.1',
			'libdns1605': '9.16.6-150300.22.13.1',
			'libdns1605-debuginfo': '9.16.6-150300.22.13.1',
			'libirs-devel': '9.16.6-150300.22.13.1',
			'libirs1601': '9.16.6-150300.22.13.1',
			'libirs1601-debuginfo': '9.16.6-150300.22.13.1',
			'libisc1606': '9.16.6-150300.22.13.1',
			'libisc1606-debuginfo': '9.16.6-150300.22.13.1',
			'libisccc1600': '9.16.6-150300.22.13.1',
			'libisccc1600-debuginfo': '9.16.6-150300.22.13.1',
			'libisccfg1600': '9.16.6-150300.22.13.1',
			'libisccfg1600-debuginfo': '9.16.6-150300.22.13.1',
			'libns1604': '9.16.6-150300.22.13.1',
			'libns1604-debuginfo': '9.16.6-150300.22.13.1',
			'python3-bind': '9.16.6-150300.22.13.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()

==> sca-patterns-sle15-1.5.8.tar.gz: sca-patterns-sle15-1.5.8/patterns/SLE/sle15sp3/bind_SUSE-SU-2021_1826-1_15.3.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for bind SUSE-SU-2021:1826-1
# Description: Security fixes for SUSE Linux Enterprise 15 SP3
# Source:      Security Announcement Parser v1.6.1
# Modified:    2021 Jul 02
#
##############################################################################
# Copyright (C) 2021 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "bind"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2021-June/008908.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'bind'
MAIN = ''
SEVERITY = 'Important'
TAG = 'SUSE-SU-2021:1826-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 15):
	if ( SERVER['DistroPatchLevel'] == 3 ):
		PACKAGES = {
			'bind-debuginfo': '9.16.6-22.7.1',
			'bind-debugsource': '9.16.6-22.7.1',
			'bind-devel': '9.16.6-22.7.1',
			'bind-utils': '9.16.6-22.7.1',
			'bind-utils-debuginfo': '9.16.6-22.7.1',
			'libbind9-1600': '9.16.6-22.7.1',
			'libbind9-1600-debuginfo': '9.16.6-22.7.1',
			'libdns1605': '9.16.6-22.7.1',
			'libdns1605-debuginfo': '9.16.6-22.7.1',
			'libirs-devel': '9.16.6-22.7.1',
			'libirs1601': '9.16.6-22.7.1',
			'libirs1601-debuginfo': '9.16.6-22.7.1',
			'libisc1606': '9.16.6-22.7.1',
			'libisc1606-debuginfo': '9.16.6-22.7.1',
			'libisccc1600': '9.16.6-22.7.1',
			'libisccc1600-debuginfo': '9.16.6-22.7.1',
			'libisccfg1600': '9.16.6-22.7.1',
			'libisccfg1600-debuginfo': '9.16.6-22.7.1',
			'libns1604': '9.16.6-22.7.1',
			'libns1604-debuginfo': '9.16.6-22.7.1',
			'python3-bind': '9.16.6-22.7.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()
